==> owncloud-app-calendar-1%3A1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/nl.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "Individual" : "Individueel",
    "Group" : "Groep",
    "Resource" : "Bron",
    "Room" : "Ruimte",
    "Unknown" : "Onbekend",
    "Required" : "Vereist",
    "Optional" : "Optioneel",
    "Does not attend" : "Neemt niet deel",
    "Please create a calendar first." : "Maak eerst een kalender aan",
    "New event" : "Nieuwe afspraak",
    "Attendees" : "Deelnemers",
    "Reminders" : "Herinneringen",
    "Repeating" : "Herhaling",
    "When shared show full event" : "Wanneer gedeeld toon gehele gebeurtenis",
    "When shared show only busy" : "Wanneer gedeeld toon enkel beschikbaarheid",
    "When shared hide this event" : "Wanneer gedeeld verberg deze gebeurtenis",
    "Please add a title!" : "Voeg een titel toe!",
    "Please select a calendar!" : "Selecteer een agenda!",
    "Global" : "Globaal",
    "None" : "Geen",
    "Every day" : "Iedere dag",
    "Every week" : "Iedere week",
    "Every month" : "Iedere maand",
    "Every year" : "Elk jaar",
    "never" : "geen",
    "after" : "na",
    "At time of event" : "Op de tijd van de afspraak",
    "5 minutes before" : "5 minuten vooraf",
    "10 minutes before" : "10 minuten vooraf",
    "15 minutes before" : "15 minuten vooraf",
    "30 minutes before" : "30 minuten vooraf",
    "1 hour before" : "1 uur vooraf",
    "2 hours before" : "2 uur vooraf",
    "Custom" : "Maatwerk",
    "Audio" : "Audio",
    "E Mail" : "E-mail",
    "Pop up" : "Pop-up",
    "sec" : "sec",
    "min" : "min",
    "hours" : "uur",
    "days" : "dagen",
    "week" : "week",
    "before" : "voor",
    "start" : "start",
    "end" : "einde",
    "Editing reminders of uknown type not supported." : "Bijwerken van herinneringen van een onbekend type is niet ondersteund.",
    "Week {number} of {year}" : "Week {number} van {year}",
    "Successfully imported" : "Succesvol geïmporteerd",
    "Partially imported, 1 failure" : "Gedeeltelijk geïmporteerd, 1 fout",
    "Partially imported, {n} failures" : "Gedeeltelijk geïmporteerd, {n} fouten",
    "Audio alarm" : "Audio alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-mail",
    "{type} {time} before the event starts" : "{type} {time} voor het begin van de afspraak",
    "{type} {time} before the event ends" : "{type} {time} voor het eind van de afspraak",
    "{type} {time} after the event starts" : "{type} {time} na het begin van de afspraak",
    "{type} {time} after the event ends" : "{type} {time} na het eind van de afspraak",
    "{type} at the event's start" : "{type} bij het begin van de afspraak",
    "{type} at the event's end" : "{type} bij het eind van de afspraak",
    "{type} at {time}" : "{type} om {time}",
    "{calendar} shared by {owner}" : "{calendar} gedeeld door {owner}",
    "Title of the Event" : "Titel van de afspraak",
    "starts" : "begint",
    "ends" : "eindigt",
    "All day Event" : "Hele dag",
    "Location" : "Locatie",
    "Delete" : "Verwijderen",
    "Cancel" : "Annuleren",
    "More ..." : "Meer...",
    "Create" : "Aanmaken",
    "Update" : "Bijwerken",
    "Close" : "Sluiten",
    "Description" : "Beschrijving",
    "Export" : "Exporteer",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Wegens een upstream bug kan de kalender nu de asset pipeline mogelijkheid niet ondersteunen.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Neem contact op met de beheerder en vraag om de configuratieoptie \"asset-pipeline.enabled\" uit te schakelen.",
    "Day" : "Dag",
    "Week" : "Week",
    "Month" : "Maand",
    "Today" : "Vandaag",
    "Share Calendar" : "Delen agenda",
    "More" : "Meer",
    "Edit" : "Bewerk",
    "CalDAV" : "CalDAV",
    "group" : "groep",
    "New Calendar" : "Nieuwe agenda",
    "Subscriptions" : "Abonnementen",
    "New Subscription" : "Nieuw abonnement",
    "Url" : "Url",
    "Edit event" : "Bewerk gebeurtenis",
    "Delete Event" : "Verwijder afspraak",
    "Save Event" : "Bewaar afspraak",
    "Time" : "Tijd",
    "Type" : "Type",
    "Relative" : "Relatief",
    "Absolute" : "Absoluut",
    "Repeat" : "Herhaling",
    "times every" : "keer elke",
    "Add" : "Toevoegen",
    "E-Mail address of attendee" : "E-mailadres van deelnemer",
    "Please add your email address in the personal settings in order to add attendees." : "Stel uw email adres in in de account instellingen om aanwezigen toe te voegen.",
    "from" : "van",
    "to" : "naar",
    "This event's repeating rule is not supported yet." : "De herhaalregel van deze afspraak wordt nog niet ondersteund.",
    "Support for advanced rules will be added with subsequent updates." : "Ondersteuning voor geavanceerde regels wordt in toekomstige releases toegevoegd.",
    "Reset repeating rule" : "Herstel de herhaalregel",
    "Repeat every ..." : "Herhaal iedere ...",
    "end repeat ..." : "eind herhalen ...",
    "times" : "keer",
    "Import Calendars" : "Importeer agenda's",
    "Import canceled" : "Importeren geannuleerd",
    "Analyzing calendar" : "Analyseren agenda",
    "The file contains objects incompatible with the selected calendar" : "Het bestand bevat objecten die niet compatible zijn met de geselecteerde agenda",
    "New calendar" : "Nieuwe agenda",
    "Import scheduled" : "Import ingepland",
    "Settings" : "Instellingen",
    "Import calendar" : "Importeer agenda",
    "No Calendars selected for import" : "Geen agenda's voor import opgegeven",
    "Primary CalDAV address" : "Primair CalDAV adres",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adres"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-calendar-1%3A1.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/nl.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "Individual" : "Individueel",
    "Group" : "Groep",
    "Resource" : "Bron",
    "Room" : "Ruimte",
    "Unknown" : "Onbekend",
    "Required" : "Vereist",
    "Optional" : "Optioneel",
    "Does not attend" : "Neemt niet deel",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "U bevindt zich in een onbekende tijdzone ({tz}), UTC zal worden gebruikt",
    "Please create a calendar first." : "Maak eerst een kalender aan",
    "New event" : "Nieuwe afspraak",
    "Attendees" : "Deelnemers",
    "Reminders" : "Herinneringen",
    "Repeating" : "Herhaling",
    "When shared show full event" : "Wanneer gedeeld toon gehele gebeurtenis",
    "When shared show only busy" : "Wanneer gedeeld toon enkel beschikbaarheid",
    "When shared hide this event" : "Wanneer gedeeld verberg deze gebeurtenis",
    "Please add a title!" : "Voeg een titel toe!",
    "Please select a calendar!" : "Selecteer een agenda!",
    "Global" : "Globaal",
    "None" : "Geen",
    "Every day" : "Iedere dag",
    "Every week" : "Iedere week",
    "Every month" : "Iedere maand",
    "Every year" : "Elk jaar",
    "never" : "geen",
    "after" : "na",
    "At time of event" : "Op de tijd van de afspraak",
    "5 minutes before" : "5 minuten vooraf",
    "10 minutes before" : "10 minuten vooraf",
    "15 minutes before" : "15 minuten vooraf",
    "30 minutes before" : "30 minuten vooraf",
    "1 hour before" : "1 uur vooraf",
    "2 hours before" : "2 uur vooraf",
    "Custom" : "Maatwerk",
    "Audio" : "Audio",
    "E Mail" : "E-mail",
    "Pop up" : "Pop-up",
    "sec" : "sec",
    "min" : "min",
    "hours" : "uur",
    "days" : "dagen",
    "week" : "week",
    "before" : "voor",
    "start" : "start",
    "end" : "einde",
    "Editing reminders of uknown type not supported." : "Bijwerken van herinneringen van een onbekend type is niet ondersteund.",
    "Week {number} of {year}" : "Week {number} van {year}",
    "Successfully imported" : "Succesvol geïmporteerd",
    "Partially imported, 1 failure" : "Gedeeltelijk geïmporteerd, 1 fout",
    "Partially imported, {n} failures" : "Gedeeltelijk geïmporteerd, {n} fouten",
    "Audio alarm" : "Audio alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-mail",
    "{type} {time} before the event starts" : "{type} {time} voor het begin van de afspraak",
    "{type} {time} before the event ends" : "{type} {time} voor het eind van de afspraak",
    "{type} {time} after the event starts" : "{type} {time} na het begin van de afspraak",
    "{type} {time} after the event ends" : "{type} {time} na het eind van de afspraak",
    "{type} at the event's start" : "{type} bij het begin van de afspraak",
    "{type} at the event's end" : "{type} bij het eind van de afspraak",
    "{type} at {time}" : "{type} om {time}",
    "{calendar} shared by {owner}" : "{calendar} gedeeld door {owner}",
    "Title of the Event" : "Titel van de afspraak",
    "starts" : "begint",
    "ends" : "eindigt",
    "All day Event" : "Hele dag",
    "Location" : "Locatie",
    "Delete" : "Verwijderen",
    "Cancel" : "Annuleren",
    "More ..." : "Meer...",
    "Create" : "Aanmaken",
    "Update" : "Bijwerken",
    "Close" : "Sluiten",
    "Description" : "Beschrijving",
    "Export" : "Exporteer",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Wegens een upstream bug kan de kalender nu de asset pipeline mogelijkheid niet ondersteunen.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Neem contact op met de beheerder en vraag om de configuratieoptie \"asset-pipeline.enabled\" uit te schakelen.",
    "Day" : "Dag",
    "Week" : "Week",
    "Month" : "Maand",
    "Today" : "Vandaag",
    "Share Calendar" : "Delen agenda",
    "More" : "Meer",
    "Edit" : "Bewerk",
    "CalDAV" : "CalDAV",
    "group" : "groep",
    "New Calendar" : "Nieuwe agenda",
    "Subscriptions" : "Abonnementen",
    "New Subscription" : "Nieuw abonnement",
    "Url" : "Url",
    "Edit event" : "Bewerk gebeurtenis",
    "Delete Event" : "Verwijder afspraak",
    "Save Event" : "Bewaar afspraak",
    "Time" : "Tijd",
    "Type" : "Type",
    "Relative" : "Relatief",
    "Absolute" : "Absoluut",
    "Repeat" : "Herhaling",
    "times every" : "keer elke",
    "Add" : "Toevoegen",
    "E-Mail address of attendee" : "E-mailadres van deelnemer",
    "Please add your email address in the personal settings in order to add attendees." : "Stel uw e-mail adres in in de account instellingen om aanwezigen toe te voegen.",
    "from" : "van",
    "to" : "naar",
    "This event's repeating rule is not supported yet." : "De herhaalregel van deze afspraak wordt nog niet ondersteund.",
    "Support for advanced rules will be added with subsequent updates." : "Ondersteuning voor geavanceerde regels wordt in toekomstige releases toegevoegd.",
    "Reset repeating rule" : "Herstel de herhaalregel",
    "Repeat every ..." : "Herhaal iedere ...",
    "end repeat ..." : "eind herhalen ...",
    "times" : "keer",
    "Import Calendars" : "Importeer agenda's",
    "Import canceled" : "Importeren geannuleerd",
    "Analyzing calendar" : "Analyseren agenda",
    "The file contains objects incompatible with the selected calendar" : "Het bestand bevat objecten die niet compatible zijn met de geselecteerde agenda",
    "New calendar" : "Nieuwe agenda",
    "Import scheduled" : "Import ingepland",
    "Settings" : "Instellingen",
    "Import calendar" : "Importeer agenda",
    "No Calendars selected for import" : "Geen agenda's voor import opgegeven",
    "Primary CalDAV address" : "Primair CalDAV adres",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adres"
},
"nplurals=2; plural=(n != 1);");
